@@ -10,4 +10,4 @@ __END__
 
 =head1 DESCRIPTION
 
-:stenciller ToUnparsedText 1-test.stencil { stencils => [0, 2] }
+:stenciller ToUnparsedText 1-test.stencil { stencils => [0, 2..4] }
